from pathlib import Path
import logging
from .system import execute_command

SEC_SWITCH_PATH = Path("/etc/dpkg/sec_switch.conf")

def _set_sec_switch_file(state: bool) -> None:
    try:
        if state:
            if SEC_SWITCH_PATH.exists():
                SEC_SWITCH_PATH.write_text('state=on\n')
                logging.info(f"Setting {SEC_SWITCH_PATH} to state=on...")
        else:
            logging.info(f"Setting {SEC_SWITCH_PATH} to state=off...")
            SEC_SWITCH_PATH.write_text('state=off\n')
    except Exception as e:
        logging.error(f"Failed to set security switch state: {e}")

def _set_sec_status(state: bool) -> None:
    """
    切换安全状态：
    - 当 state 为 True 时，执行禁用安全状态。
    - 当 state 为 False 时，恢复默认安全状态。
    """
    try:
        if state:
            pass
        else:
            logging.info("Disabling security status...")
            execute_command("setstatus disable")
    except Exception as e:
        logging.error(f"Failed to update security status (state={state}): {e}")

def shutdown_security_fun():
    _set_sec_switch_file(False)
    _set_sec_status(False)

def restore_security_fun():
    _set_sec_switch_file(True)
    _set_sec_status(True)