import subprocess
import logging

def run_system(args,timeout=1):
    try:
        p = subprocess.run(args,timeout=timeout)
        if p.returncode == 0:
            logging.info("run %r to success...",args)
            return True
        else:
            logging.info("run %r to failed...",args)
            return False
    except Exception as exc:
        logging.error(exc)

def execute_command(hook: str):
    """
    执行 shell 命令 hook。
    - 返回 (True, None) 表示执行成功且无错误输出。
    - 返回 (False, stderr) 表示执行失败或有错误输出。
    """
    if not hook:
        logging.info("No hook to execute.")
        return True, None  # 空钩子不视为错误

    try:
        logging.info(f"Executing hook: {hook}")
        result = subprocess.run(hook, shell=True, text=True, capture_output=True)

        if result.stdout:
            logging.info(f"Stdout: {result.stdout.strip()}")

        stderr = result.stderr.strip() if result.stderr else None
        if stderr:
            logging.warning(f"Stderr: {stderr}")

        if result.returncode == 0 and not stderr:
            return True, None
        else:
            return False, stderr or "Non-zero return code without stderr."

    except Exception as ex:
        logging.error(f"Failed to execute hook '{hook}': {str(ex)}")
        return False, str(ex)

